@@ -1,7 +1,7 @@
 import subprocess
 from six import with_metaclass
 
-from jac.compat import file
+from jac.compat import file, u, utf8_encode
 
 from . import CompilerMeta
 
@@ -19,14 +19,15 @@ class SassCompiler(with_metaclass(CompilerMeta, object)):
         if cwd:
             args += ['-I', cwd]
 
-        handler = subprocess.Popen(args, universal_newlines=True,
+        handler = subprocess.Popen(args,
                                    stdout=subprocess.PIPE,
                                    stdin=subprocess.PIPE,
                                    stderr=subprocess.PIPE, cwd=None)
 
         if isinstance(what, file):
             what = what.read()
-        (stdout, stderr) = handler.communicate(input=what)
+        (stdout, stderr) = handler.communicate(input=utf8_encode(what))
+        stdout = u(stdout)
 
         if handler.returncode == 0:
             return stdout
